/*
 * Copyright © 2022 Soren Stoutner <soren@stoutner.com>.
 *
 * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc>.
 *
 * Privacy Browser PC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Privacy Browser PC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
 */

// Application headers.
#include "browserwindow.h"

// KDE Frameworks headers.
#include <KAboutData>
#include <KCrash>
#include <KLocalizedString>
#include <KDBusService>

// Qt headers.
#include <QApplication>
#include <QCommandLineParser>
#include <QFile>

int main(int argc, char *argv[])
{
    // Create the application.
    QApplication application(argc, argv);

    // Set the localization application domain.
    KLocalizedString::setApplicationDomain("privacybrowser");

    // Initialize KCrash.
    KCrash::initialize();

    // Instantiate about data, setting the component name, the display name, and the version.
    KAboutData aboutData(QStringLiteral("privacybrowser"), i18n("Privacy Browser"), QStringLiteral("0.1"));

    // Add the author name, job description, email address, and website.
    aboutData.addAuthor(i18n("Soren Stoutner"),i18n("Principal developer"), QStringLiteral("soren@stoutner.com"), QStringLiteral("https://www.stoutner.com/"));

    // Populate additional about data info.
    aboutData.setBugAddress("https://redmine.stoutner.com/projects/privacy-browser-pc/issues");
    aboutData.setCopyrightStatement(i18n("Copyright © 2016-2017,2021-2022 Soren Stoutner <soren@stoutner.com>"));
    aboutData.setDesktopFileName(QStringLiteral("com.stoutner.privacybrowser"));
    aboutData.setHomepage(QStringLiteral("https://www.stoutner.com/privacy-browser-pc/"));
    aboutData.setLicenseTextFile(":/licenses/GPLv3+.txt");
    aboutData.setOrganizationDomain("stoutner.com");
    aboutData.setShortDescription(i18n("A web browser that respects your privacy."));

    // Set the application data.
    KAboutData::setApplicationData(aboutData);

    // Set the window icon.
    application.setWindowIcon(QIcon::fromTheme(QStringLiteral("privacy-browser"), QIcon(":/icons/sc-apps-privacy-browser.svg")));

    // Create a command line parser.
    QCommandLineParser commandLineParser;

    // Process the command line through about data (this adds --license and --author).
    aboutData.setupCommandLine(&commandLineParser);

    // Process the application command line options (this adds --version, --help, and --help-all).
    commandLineParser.process(application);

    // Make it so.
    aboutData.processCommandLine(&commandLineParser);

    // Register with D-Bus, allowing multiple instances and allowing the program to run if for some reason the registration fails.
    KDBusService appDBusService(KDBusService::Multiple | KDBusService::NoExitOnFailure);

    // Create the main window.
    BrowserWindow *browserWindowPointer = new BrowserWindow;

    // Show the main window.
    browserWindowPointer->show();

    // Return the application.
    return application.exec();
}
